<?php

namespace App\Controller;

use App\Connexion;
use App\Gateway\AuthGateway;
use App\Gateway\TacticInfoGateway;
use App\Gateway\TeamGateway;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\AuthModel;
use App\Model\TacticModel;
use App\Model\TeamModel;

class UserController {
    public function home(): HttpResponse {
        return ViewHttpResponse::twig("home.twig", []);
    }

    public function register(): HttpResponse {
        $model = new AuthModel(new AuthGateway(new Connexion(get_database())));
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return (new Sub\AuthController($model))->displayRegister();
        }
        return (new Sub\AuthController($model))->confirmRegister($_POST);
    }

    public function login(): HttpResponse {
        $model = new AuthModel(new AuthGateway(new Connexion(get_database())));
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return (new Sub\AuthController($model))->displayLogin();
        }
        return (new Sub\AuthController($model))->confirmLogin($_POST);
    }

    public function open(int $id): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\VisualizerController($model))->visualize($id);
    }

    public function edit(int $id): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\EditorController($model))->edit($id);
    }

    public function create(): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\EditorController($model))->createNew();
    }

    public function createTeam(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displaySubmitTeam();
        }
        return $ctrl->submitTeam($_POST);
    }

    public function listTeams(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displayListTeamByName();
        }
        return $ctrl->listTeamByName($_POST);
    }

    public function getTeam(int $id): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        return $ctrl->getTeam($id);
    }
}
